==> haskell-prelude-extras-0.4.0.3-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-prelude-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prelude-extras
version: 0.4.0.3
id: prelude-extras-0.4.0.3-BhL9U5k7NtGJn1itwIHt2Y
key: prelude-extras-0.4.0.3-BhL9U5k7NtGJn1itwIHt2Y
license: BSD3
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/prelude-extras
synopsis: Higher order versions of Prelude classes
description:
    Higher order versions of Prelude classes to ease programming with polymorphic recursion and reduce UndecidableInstances
    .
    See <http://flint.cs.yale.edu/trifonov/papers/sqcc.pdf> for further discussion of the approach taken here.
category: Polymorphism, Combinators
author: Edward A. Kmett
exposed: True
exposed-modules:
    Prelude.Extras
abi: dfbcb3cce7f0051b31972f9f972f65b9
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/prelude-extras-0.4.0.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/prelude-extras-0.4.0.3
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/prelude-extras-0.4.0.3
hs-libraries: HSprelude-extras-0.4.0.3-BhL9U5k7NtGJn1itwIHt2Y
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-prelude-extras/html/prelude-extras.haddock
haddock-html: /usr/share/doc/haskell-prelude-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prelude-extras-0.4.0.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-prelude-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prelude-extras
version: 0.4.0.3
id: prelude-extras-0.4.0.3-E2TUDUJSI3wDl8mkUzsaKv
key: prelude-extras-0.4.0.3-E2TUDUJSI3wDl8mkUzsaKv
license: BSD3
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/prelude-extras
synopsis: Higher order versions of Prelude classes
description:
    Higher order versions of Prelude classes to ease programming with polymorphic recursion and reduce UndecidableInstances
    .
    See <http://flint.cs.yale.edu/trifonov/papers/sqcc.pdf> for further discussion of the approach taken here.
category: Polymorphism, Combinators
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Prelude.Extras
abi: 3410dd613bd435c82e4134717cf6d9ef
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/prelude-extras-0.4.0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/prelude-extras-0.4.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/prelude-extras-0.4.0.3
hs-libraries: HSprelude-extras-0.4.0.3-E2TUDUJSI3wDl8mkUzsaKv
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-prelude-extras/html/prelude-extras.haddock
haddock-html: /usr/share/doc/haskell-prelude-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
